@@ -11,7 +11,7 @@ use Carp;
 
 use vars qw($VERSION);
 
-$VERSION = '0.2.1';
+$VERSION = '0.5.1';
 
 # ----------------------------------------------------------------------------
 # Private methods
@@ -49,11 +49,21 @@ sub _dir_compare
     }
     # In both
     else {
+      # Both symlinks
+      if (-l $f1 && -l $f2) {
+        my $t1 = readlink $f1 or croak "Cannot read symlink $f1: $!";
+        my $t2 = readlink $f2 or croak "Cannot read symlink $f2: $!";
+        $sub->($f1, $f2) if $t1 ne $t2;
+      }
+      # One symlink (i.e. different)
+      elsif (-l $f1 || -l $f2) {
+        $sub->($f1, $f2);
+      }
       # Both directories
-      if (-d $f1 && -d $f2) {
+      elsif (-d $f1 && -d $f2) {
         $self->_dir_compare($f1, $f2, $sub, $opts);
       }
-      # One directory
+      # One directory (i.e. different)
       elsif (-d $f1 || -d $f2) {
         $sub->($f1, $f2);
       }
@@ -128,7 +138,7 @@ callbacks.
 
   # Version-control like Deleted/Added/Modified listing
   my (@listing, @modified);     # use closure to collect results
-  File::DirCompare->compare('old_tree', 'new_tree'), sub {
+  File::DirCompare->compare('old_tree', 'new_tree', sub {
     my ($a, $b) = @_;
     if (! $b) {
       push @listing, "D   $a";
